
# Slot: subject


A genotype that has a role in modeling the disease.

URI: [biolink:genotype_as_a_model_of_disease_association_subject](https://w3id.org/biolink/vocab/genotype_as_a_model_of_disease_association_subject)


## Domain and Range

[GenotypeAsAModelOfDiseaseAssociation](GenotypeAsAModelOfDiseaseAssociation.md) &#8594;  <sub>1..1</sub> [Genotype](Genotype.md)

## Parents

 *  is_a: [genotype to disease association➞subject](genotype_to_disease_association_subject.md)

## Children


## Used by

 * [GenotypeAsAModelOfDiseaseAssociation](GenotypeAsAModelOfDiseaseAssociation.md)
